# This file is part of python-cinema-club-bot
# contributed in 2024 by Mikhail Kirillov (~w96k) <w96k@runbox.com>

# To the extent possible under law, the author(s) have dedicated all copyright
# and related and neighboring rights to this software to the public domain
# worldwide. This software is distributed without any warranty.

# You should have received a copy of the CC0 Public Domain Dedication along
# with this software. If not, see:
# <http://creativecommons.org/publicdomain/zero/1.0/>

from telegram import Update
from telegram.ext import ApplicationBuilder, CommandHandler, ContextTypes, \
    MessageHandler, filters
from dotenv import load_dotenv
import os
import logging

from strings import INVALID_COMMAND
from persistence import Persistence
import commands


load_dotenv()

logging.basicConfig(
    level=logging.INFO,
    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s'
)


async def unknown(update: Update, context: ContextTypes.DEFAULT_TYPE):
    await context.bot.send_message(
        chat_id=update.effective_chat.id,
        text=INVALID_COMMAND
    )

async def error_handler(update: object, context: ContextTypes.DEFAULT_TYPE) -> None:
    logging.error("Exception:", exc_info=context.error)

    await context.bot.send_message(
        chat_id=update.effective_chat.id,
        text=context.error.message
    )

if __name__ == "__main__":
    app = ApplicationBuilder().token(
        os.environ.get("TELEGRAM_TOKEN")
    ).persistence(Persistence).build()

    # Meta commands
    app.add_handler(CommandHandler("about", commands.about))

    # Movie commands
    app.add_handler(CommandHandler("set", commands.set_users))
    app.add_handler(CommandHandler("add", commands.add_users))
    app.add_handler(CommandHandler("list", commands.list_users))
    app.add_handler(CommandHandler("remove", commands.remove_users))
    app.add_handler(CommandHandler("chooser", commands.chooser_user))

    app.add_handler(MessageHandler(filters.COMMAND, unknown))
    app.add_error_handler(error_handler)


    app.run_polling()

